summaryrefslogtreecommitdiffstats
path: root/chromium/third_party/WebKit/Source/core/frame/DOMWindowProperty.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/WebKit/Source/core/frame/DOMWindowProperty.cpp')
-rw-r--r--chromium/third_party/WebKit/Source/core/frame/DOMWindowProperty.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/chromium/third_party/WebKit/Source/core/frame/DOMWindowProperty.cpp b/chromium/third_party/WebKit/Source/core/frame/DOMWindowProperty.cpp
index 6649a2f7947..785b61519eb 100644
--- a/chromium/third_party/WebKit/Source/core/frame/DOMWindowProperty.cpp
+++ b/chromium/third_party/WebKit/Source/core/frame/DOMWindowProperty.cpp
@@ -28,12 +28,12 @@
#include "core/frame/DOMWindowProperty.h"
#include "core/dom/Document.h"
-#include "core/frame/DOMWindow.h"
-#include "core/frame/Frame.h"
+#include "core/frame/LocalDOMWindow.h"
+#include "core/frame/LocalFrame.h"
namespace WebCore {
-DOMWindowProperty::DOMWindowProperty(Frame* frame)
+DOMWindowProperty::DOMWindowProperty(LocalFrame* frame)
: m_frame(frame)
, m_associatedDOMWindow(0)
{
@@ -57,12 +57,12 @@ DOMWindowProperty::~DOMWindowProperty()
void DOMWindowProperty::willDestroyGlobalObjectInFrame()
{
// If the property is getting this callback it must have been created with a Frame/DOMWindow and it should still have them.
ASSERT(m_frame);
ASSERT(m_associatedDOMWindow);
// DOMWindowProperty lifetime isn't tied directly to the DOMWindow itself so it is important that it unregister
// itself from any DOMWindow it is associated with if that DOMWindow is going away.
if (m_associatedDOMWindow)
m_associatedDOMWindow->unregisterProperty(this);
m_associatedDOMWindow = 0;
@@ -71,7 +71,7 @@ void DOMWindowProperty::willDestroyGlobalObjectInFrame()
void DOMWindowProperty::willDetachGlobalObjectFromFrame()
{
// If the property is getting this callback it must have been created with a Frame/DOMWindow and it should still have them.
ASSERT(m_frame);
ASSERT(m_associatedDOMWindow);
}
@@ -57,12 +57,12 @@ DOMWindowProperty::~DOMWindowProperty()
void DOMWindowProperty::willDestroyGlobalObjectInFrame()
{
- // If the property is getting this callback it must have been created with a Frame/DOMWindow and it should still have them.
+ // If the property is getting this callback it must have been created with a LocalFrame/LocalDOMWindow and it should still have them.
ASSERT(m_frame);
ASSERT(m_associatedDOMWindow);
@@ -57,12 +57,12 @@ DOMWindowProperty::~DOMWindowProperty()
ASSERT(m_frame);
ASSERT(m_associatedDOMWindow);
- // DOMWindowProperty lifetime isn't tied directly to the DOMWindow itself so it is important that it unregister
- // itself from any DOMWindow it is associated with if that DOMWindow is going away.
+ // DOMWindowProperty lifetime isn't tied directly to the LocalDOMWindow itself so it is important that it unregister
+ // itself from any LocalDOMWindow it is associated with if that LocalDOMWindow is going away.
if (m_associatedDOMWindow)
m_associatedDOMWindow->unregisterProperty(this);
@@ -71,7 +71,7 @@ void DOMWindowProperty::willDestroyGlobalObjectInFrame()
void DOMWindowProperty::willDetachGlobalObjectFromFrame()
{
- // If the property is getting this callback it must have been created with a Frame/DOMWindow and it should still have them.
+ // If the property is getting this callback it must have been created with a LocalFrame/LocalDOMWindow and it should still have them.
ASSERT(m_frame);
ASSERT(m_associatedDOMWindow);